ploneintranet.messaging.tests package
=====================================

Submodules
----------

ploneintranet.messaging.tests.test_api module
---------------------------------------------

.. automodule:: ploneintranet.messaging.tests.test_api
    :members:
    :undoc-members:
    :show-inheritance:

ploneintranet.messaging.tests.test_doctests module
--------------------------------------------------

.. automodule:: ploneintranet.messaging.tests.test_doctests
    :members:
    :undoc-members:
    :show-inheritance:

ploneintranet.messaging.tests.test_messaging module
---------------------------------------------------

.. automodule:: ploneintranet.messaging.tests.test_messaging
    :members:
    :undoc-members:
    :show-inheritance:

ploneintranet.messaging.tests.test_setup module
-----------------------------------------------

.. automodule:: ploneintranet.messaging.tests.test_setup
    :members:
    :undoc-members:
    :show-inheritance:

ploneintranet.messaging.tests.test_views module
-----------------------------------------------

.. automodule:: ploneintranet.messaging.tests.test_views
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: ploneintranet.messaging.tests
    :members:
    :undoc-members:
    :show-inheritance:
